@@ -37,13 +37,15 @@ from gi.repository import GLib
 from gi.repository import UPowerGlib
 from gi.repository import UMockdev
 
-class PowerPluginTest(gsdtestcase.GSDTestCase):
+class PowerPluginBase(gsdtestcase.GSDTestCase):
     '''Test the power plugin'''
 
     COMMON_SUSPEND_METHODS=['Suspend', 'Hibernate', 'SuspendThenHibernate']
 
     def setUp(self):
-        os.environ['GSD_MOCKED']='1'
+        self.mock_external_monitor_file = os.path.join(self.workdir, 'GSD_MOCK_EXTERNAL_MONITOR')
+        os.environ['GSD_MOCK_EXTERNAL_MONITOR_FILE'] = self.mock_external_monitor_file
+
         self.check_logind_gnome_session()
         self.start_logind()
         self.daemon_death_expected = False
@@ -168,7 +170,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         Gio.Settings.sync()
 
         try:
-            os.unlink('GSD_MOCK_EXTERNAL_MONITOR')
+            os.unlink(self.mock_external_monitor_file)
         except OSError:
             pass
 
@@ -255,7 +257,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
             val = b'1'
         else:
             val = b'0'
-        GLib.file_set_contents ('GSD_MOCK_EXTERNAL_MONITOR', val)
+        GLib.file_set_contents (self.mock_external_monitor_file, val)
 
     def set_composite_battery_discharging(self, icon='battery-good-symbolic'):
         self.obj_upower.SetupDisplayDevice(
@@ -478,6 +480,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         log = self.plugin_log.read()
         self.assertFalse(b'TESTSUITE: Unblanked screen' in log, 'unexpected unblank request')
 
+class PowerPluginTest1(PowerPluginBase):
     def test_screensaver(self):
         # Note that the screensaver mock object
         # doesn't know how to get out of being active,
@@ -548,6 +551,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.obj_session_mgr.Uninhibit(dbus.UInt32(inhibit_id),
                 dbus_interface='org.gnome.SessionManager')
 
+class PowerPluginTest2(PowerPluginBase):
     def test_screensaver_no_unblank(self):
         '''Ensure the screensaver is not unblanked for new inhibitors.'''
 
@@ -627,9 +631,9 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         # And check we're not idle
         self.assertEqual(self.get_status(), gsdpowerenums.GSM_PRESENCE_STATUS_AVAILABLE)
 
-    def test_sleep_inactive_battery_hibernate_then_suspend(self):
-        '''Verify we SuspendThenHibernate on sleep-inactive-battery-timeout when SuspendThenHibernate is available'''
-        # Hibernate then suspend is the default
+class PowerPluginTest3(PowerPluginBase):
+    def test_sleep_inactive_battery(self):
+        '''sleep-inactive-battery-timeout'''
 
         self.settings_session['idle-delay'] = 2
         self.settings_gsd_power['sleep-inactive-battery-timeout'] = 5
@@ -640,24 +644,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
 
         # suspend should happen after inactive sleep timeout + 1 s notification
         # delay + 1 s error margin
-        self.check_for_suspend(7, methods=['SuspendThenHibernate'])
-
-    def test_sleep_inactive_battery_no_hibernate_then_suspend(self):
-        '''Verify we Suspend on sleep-inactive-battery-timeout when SuspendThenHibernate is unavailable'''
-
-        # Patch up logind_ctl to not return "yes" for CanSuspendThenHibernate
-        self.logind_obj.AddMethod('org.freedesktop.login1.Manager', 'CanSuspendThenHibernate', '', 's', 'ret = "no"')
-
-        self.settings_session['idle-delay'] = 2
-        self.settings_gsd_power['sleep-inactive-battery-timeout'] = 5
-        self.settings_gsd_power['sleep-inactive-battery-type'] = 'suspend'
-
-        # wait for idle delay; should not yet suspend
-        self.check_no_suspend(2)
-
-        # suspend should happen after inactive sleep timeout + 1 s notification
-        # delay + 1 s error margin
-        self.check_for_suspend(7, methods=["Suspend"])
+        self.check_for_suspend(7)
 
     def _test_suspend_no_hibernate(self):
         '''suspend-no-hibernate'''
@@ -698,6 +685,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.obj_session_mgr.Uninhibit(dbus.UInt32(inhibit_id),
                 dbus_interface='org.gnome.SessionManager')
 
+class PowerPluginTest4(PowerPluginBase):
     def test_lock_on_lid_close(self):
         '''Check that we do lock on lid closing, if the machine will not suspend'''
 
@@ -778,6 +766,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.obj_session_mgr.Uninhibit(dbus.UInt32(inhibit_id),
                 dbus_interface='org.gnome.SessionManager')
 
+class PowerPluginTest5(PowerPluginBase):
     def test_dim(self):
         '''Check that we do go to dim'''
 
@@ -851,6 +840,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         # Check that we're uninhibited after the safety time
         self.check_for_lid_uninhibited(4)
 
+class PowerPluginTest6(PowerPluginBase):
     def test_notify_critical_battery(self):
         '''action on critical battery'''
 
@@ -975,6 +965,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.obj_session_mgr.Uninhibit(dbus.UInt32(inhibit_id),
                 dbus_interface='org.gnome.SessionManager')
 
+class PowerPluginTest7(PowerPluginBase):
     def test_check_missing_kbd_brightness(self):
         ''' https://bugzilla.gnome.org/show_bug.cgi?id=793512 '''
 
@@ -1048,6 +1039,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         # And wait a little more to see us dim again
         self.check_dim(idle_delay + 2)
 
+class PowerPluginTest8(PowerPluginBase):
     def test_brightness_stepping(self):
         '''Check that stepping the backlight works as expected'''
 
@@ -1067,9 +1059,9 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         obj_gsd_power_screen_iface.StepUp()
         self.assertEqual(self.get_brightness(), 70)
         stop = time.time()
-        # This needs to take more than 0.4 seconds as each write is delayed by
-        # 0.1 seconds by the test backlight helper
-        self.assertGreater(stop - start, 0.4)
+        # This needs to take more than 0.8 seconds as each write is delayed by
+        # 0.2 seconds by the test backlight helper
+        self.assertGreater(stop - start, 0.8)
 
         # Now, the same thing should work fine if we step multiple times,
         # even if we are so quick that compression will happen.
@@ -1101,8 +1093,8 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.assertEqual(replies[0], 4)
         # Four steps down, so back at 50%
         self.assertEqual(self.get_brightness(), 50)
-        # And compression must have happened, so it should take less than 0.4s
-        self.assertLess(stop - start, 0.4)
+        # And compression must have happened, so it should take less than 0.8s
+        self.assertLess(stop - start, 0.8)
 
     def test_brightness_compression(self):
         '''Check that compression also happens when setting the property'''
@@ -1122,9 +1114,9 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
             obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', brightness)
 
         # The brightness of 80 should be in effect after slightly more than
-        # 0.2 seconds. If compression does not work as expected, this would take
-        # more than 2 seconds for the 20 steps.
-        time.sleep(1.0)
+        # 0.4 seconds. If compression does not work as expected, this would take
+        # more than 5 seconds for the 20 steps.
+        time.sleep(2.0)
         self.assertEqual(self.get_brightness(), 90)
 
     def test_brightness_uevent(self):
@@ -1142,7 +1134,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.testbed.uevent(self.backlight, 'change')
 
         self.check_plugin_log('GsdBacklight: Got uevent', 1, 'gsd-power did not process uevent')
-        time.sleep(0.1)
+        time.sleep(0.2)
 
         brightness = obj_gsd_power_prop_iface.Get('org.gnome.SettingsDaemon.Power.Screen', 'Brightness')
         self.assertEqual(80, brightness)
@@ -1165,31 +1157,31 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         obj_gsd_power_prop_iface = dbus.Interface(obj_gsd_power, dbus.PROPERTIES_IFACE)
 
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 0)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 0)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 10)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 1)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 20)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 3)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 25)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 4)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 50)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 7)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 52)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 8)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 56)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 8)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 57)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 9)
         obj_gsd_power_prop_iface.Set('org.gnome.SettingsDaemon.Power.Screen', 'Brightness', 98)
-        time.sleep(0.2)
+        time.sleep(0.4)
         self.assertEqual(self.get_brightness(), 15)
 
     def test_no_backlight(self):
